@@ -1,4 +1,3 @@
-
 #' @title Epidemic Parameters for Stochastic Network Models
 #'
 #' @description Sets the epidemic parameters for stochastic network models
@@ -207,13 +206,13 @@ param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
 
   ## Defaults and Checks
   if ("b.rate" %in% names.dot.args) {
-    p$a.rate <- dot.args$b.rate
+    p[["a.rate"]] <- dot.args[["b.rate"]]
     stop("EpiModel 1.7.0 onward renamed the birth rate parameter b.rate
          to a.rate. ", "See documentation for details.",
          call. = FALSE)
   }
   if ("b.rate.g2" %in% names.dot.args) {
-    p$a.rate.g2 <- dot.args$b.rate.g2
+    p[["a.rate.g2"]] <- dot.args[["b.rate.g2"]]
     stop("EpiModel 1.7.0 onward renamed the birth rate parameter b.rate.g2 to
          a.rate.g2. ", "See documentation for details.",
          call. = FALSE)
@@ -227,9 +226,9 @@ param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
 
   }
   if (missing(act.rate)) {
-    p$act.rate <- 1
+    p[["act.rate"]] <- 1
   }
-  p$vital <- ifelse(!missing(a.rate) | !missing(ds.rate) |
+  p[["vital"]] <- ifelse(!missing(a.rate) | !missing(ds.rate) |
                       !missing(di.rate) | !missing(dr.rate), TRUE, FALSE)
   if ("act.rate.g2" %in% names.dot.args) {
     warning("act.rate.g2 parameter was entered. ",
@@ -237,8 +236,8 @@ param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
             call. = FALSE)
   }
 
-  if (!is.null(p$inter.eff) && is.null(p$inter.start)) {
-    p$inter.start <- 1
+  if (!is.null(p[["inter.eff"]]) && is.null(p[["inter.start"]])) {
+    p[["inter.start"]] <- 1
   }
 
   ## Output
@@ -358,11 +357,29 @@ param_random <- function(values, prob = NULL) {
 #' The function used inside \code{random_params} must be 0 argument functions
 #' returning a valid value for the parameter with the same name.
 #'
+#' @section \code{param_random_set}:
+#' The \code{random_params} list can optionnally contain a
+#' \code{param_random_set} element. It must be a \code{data.frame} of possible
+#' values to be used as parameters.
+#'
+#' The column names must correspond either to:
+#' the name of one parameter if this parameter is of size 1 or the name of the
+#' parameter with "_1", "_2", "_N" with the second part being the position of
+#' the value for a parameter of size > 1. This means that the parameter names
+#' cannot contain any underscore "_" if you intend to use
+#' \code{param_random_set}.
+#'
+#' The point of the \code{param_random_set} \code{data.frame} is to allow the
+#' random parameters to be correlated. To achieve this, a whole row of the
+#' \code{data.frame} is selected for each simulation.
+#'
 #' @export
 #'
 #' @examples
 #' \dontrun{
 #'
+#' ## Example with only the generator function
+#'
 #' # Define random parameter list
 #' my_randoms <- list(
 #'   act.rate = param_random(c(0.25, 0.5, 0.75)),
@@ -382,7 +399,42 @@ param_random <- function(values, prob = NULL) {
 #' # therefore produced.
 #' param <- param.net(tx.prob = 0.3, random.params = my_randoms)
 #'
-
+#'
+#' # Parameters are drawn automatically in netsim by calling the function
+#' # within netsim_loop. Demonstrating draws here but this is not used by
+#' # end user.
+#' paramDraw <- generate_random_params(param, verbose = TRUE)
+#' paramDraw
+#'
+#'
+#' ## Addition of the `param_random_set` `data.frame`
+#'
+#' # This function will generate sets of correlated parameters
+#'  generate_correlated_params <- function() {
+#'    param.unique <- runif(1)
+#'    param.set.1 <- param.unique + runif(2)
+#'    param.set.2 <- param.unique * rnorm(3)
+#'
+#'    return(list(param.unique, param.set.1, param.set.2))
+#'  }
+#'
+#'  # Data.frame set of random parameters :
+#'  correlated_params <- t(replicate(10, unlist(generate_correlated_params())))
+#'  correlated_params <- as.data.frame(correlated_params)
+#'  colnames(correlated_params) <- c(
+#'    "param.unique",
+#'    "param.set.1_1", "param.set.1_2",
+#'    "param.set.2_1", "param.set.2_2", "param.set.2_3"
+#'  )
+#'
+#' # Define random parameter list with the `param_random_set` element
+#' my_randoms <- list(
+#'   act.rate = param_random(c(0.25, 0.5, 0.75)),
+#'   param_random_set = correlated_params
+#' )
+#'
+#' # Parameter model with fixed and random parameters
+#' param <- param.net(inf.prob = 0.3, random.params = my_randoms)
 #'
 #' # Parameters are drawn automatically in netsim by calling the function
 #' # within netsim_loop. Demonstrating draws here but this is not used by
@@ -391,36 +443,99 @@ param_random <- function(values, prob = NULL) {
 #' paramDraw
 #'
 #' }
-#'
 generate_random_params <- function(param, verbose = FALSE) {
-  if (is.null(param$random.params) || length(param$random.params) == 0) {
+  if (is.null(param[["random.params"]]) ||
+      length(param[["random.params"]]) == 0) {
     return(param)
+  } else {
+    random.params <- param[["random.params"]]
   }
 
-  if (!is.list(param$random.params)) {
+  if (!is.list(random.params)) {
     stop("`random.params` must be named list of functions")
   }
 
-  rng_names <- names(param$random.params)
+  rng_names <- names(random.params)
   if (any(rng_names == "")) {
     stop("all elements of `random.params` must be named")
   }
 
-  if (!all(vapply(param$random.params, is.function, TRUE))) {
-    stop("all elements of `random.params` must be functions")
+  rng_values <- list()
+
+  if ("param_random_set" %in% rng_names) {
+    # Take `param_random_set` out of the `random.params` list
+    param_random_set <- random.params[["param_random_set"]]
+    random.params[["param_random_set"]] <- NULL
+    rng_names <- names(random.params)
+
+    if (!is.data.frame(param_random_set)) {
+      stop("`param_random_set` must be a data.frame")
+    }
+
+    # Check the format of the names
+    set.elements <- names(param_random_set)
+    correct_format <- grepl("^[a-zA-Z0-9.]*(_[0-9]+)?$", set.elements)
+    if (!all(correct_format)) {
+      stop("The following column names in `param_random_set` are malformed: \n",
+        paste0(set.elements[!correct_format], collapse = ", "), "\n\n",
+        "you can check the names with ",
+        '`grepl("^[a-zA-Z0-9.]*(_[0-9]+)?$", your.names)` \n',
+        "Example: 'unique.param', 'param.set_1', 'param.set_2'"
+      )
+    }
+
+    # Construct a `data.frame` matching the names with the parameters
+    set.elements <- names(param_random_set)
+    set.elements.split <- data.frame(do.call(
+      rbind,
+      strsplit(set.elements, "_")
+    ))
+
+    nums <- grepl("^[0-9]+$", set.elements.split[, 2])
+    set.elements.split[, 2] <- as.numeric(
+      ifelse(nums, set.elements.split[, 2], "1")
+    )
+
+    set.elements <- cbind(set.elements, set.elements.split)
+    colnames(set.elements) <- c("name", "param", "position")
+
+    # Pick one row of the `data.frame`
+    sampled.row <- sample.int(nrow(param_random_set), 1)
+    param_random_set <- param_random_set[sampled.row, ]
+
+    # Set the new values in `rng_values`
+    for (i in seq_len(nrow(set.elements))) {
+      value <- param_random_set[1, set.elements[i, "name"][[1]]]
+      parameter <- set.elements[i, "param"][[1]]
+      position <- set.elements[i, "position"][[1]]
+
+      rng_values[[parameter]][position] <- value
+    }
   }
 
-  rng_values <- list()
-  rng_values[rng_names] <- lapply(param$random.params, do.call, args = list())
+  if (!all(vapply(random.params, is.function, TRUE))) {
+    stop("all elements of `random.params` must be functions \n",
+         "(Except 'param_random_set')")
+  }
+
+  duplicated.rng <- names(rng_values) %in% rng_names
+  if (any(duplicated.rng)) {
+    warning("Some parameters are set to be randomly assigned twice: \n",
+            paste0(rng_names[duplicated.rng], collapse = ", "), "\n\n",
+            "The version from a generator function will be used")
+  }
+
+  rng_values[rng_names] <- lapply(random.params, do.call, args = list())
   for (nm in rng_names) {
     param[nm] <- rng_values[nm]
   }
-  param$random.params.values <- rng_values
+
+  param[["random.params.values"]] <- rng_values
 
   if (verbose == TRUE) {
     msg <-
      "The following values were randomly generated for the given parameters: \n"
-    msg <- c(msg, paste0("`", rng_names, "`: ", rng_values, "\n"))
+    msg <- c(msg, paste0("`", names(rng_values), "`: ", rng_values, "\n"))
     message(msg)
   }
 
@@ -506,14 +621,14 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
     warning("EpiModel 2.0+ updated initial condition suffixes. ",
             "All .m2 initial conditions changed to .g2. See documentation.")
   }
-  if (!is.null(p$i.num) & !is.null(p$status.vector)) {
+  if (!is.null(p[["i.num"]]) & !is.null(p[["status.vector"]])) {
     stop("Use i.num OR status.vector to set initial infected")
   }
-  if (!is.null(p$infTime.vector) & is.null(p$status.vector)) {
+  if (!is.null(p[["infTime.vector"]]) & is.null(p[["status.vector"]])) {
     stop("infTime.vector may only be used if status.vector is used")
   }
-  if (!is.null(p$infTime.vector) &
-      length(p$infTime.vector) != length(p$status.vector)) {
+  if (!is.null(p[["infTime.vector"]]) &
+      length(p[["infTime.vector"]]) != length(p[["status.vector"]])) {
     stop("Length of infTime.vector must match length of status.vector")
   }
 
@@ -616,14 +731,11 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
 #'        of the networks passed to \code{init_tergmLite}, with \code{time}
 #'        defaulting to \code{0} and \code{lasttoggle} defaulting to all
 #'        \code{lasttoggle} times unspecified (effectively \code{-INT_MAX/2}).
-#' @param set.control.ergm Control arguments passed to \code{simulate.ergm}. See
-#'        the help file for \code{\link{netdx}} for details and examples on
-#'        specifying this parameter.
-#' @param set.control.stergm Control arguments passed to \code{simulate.stergm}.
-#'        See the help file for \code{\link{netdx}} for details and examples on
-#'        specifying this parameter.
-#' @param mcmc.control.tergm,mcmc.control.ergm Control arguments for network
-#'        simulation in \code{tergmLite}.
+#' @param set.control.ergm Control arguments passed to \code{ergm}'s
+#'        \code{.simulate_formula.network}.
+#' @param set.control.stergm Control arguments passed to \code{tergm}'s
+#'        \code{simulate.network}. See the help file for \code{\link{netdx}}
+#'        for details and examples on specifying this parameter.
 #' @param ... Additional control settings passed to model.
 #'
 #' @details
@@ -708,10 +820,9 @@ control.net <- function(type,
                         skip.check = FALSE,
                         raw.output = FALSE,
                         tergmLite.track.duration = FALSE,
-                        set.control.ergm = control.simulate.ergm(MCMC.burnin = 2e5),
-                        set.control.stergm = control.simulate.network(MCMC.burnin.min = 1000),
-                        mcmc.control.ergm = control.simulate.formula(),
-                        mcmc.control.tergm = control.simulate.formula.tergm(),
+                        set.control.ergm = control.simulate.formula(
+                          MCMC.burnin = 2e5),
+                        set.control.stergm = control.simulate.network(),
                         ...) {
 
   # Get arguments
@@ -732,20 +843,20 @@ control.net <- function(type,
   }
 
   if ("births.FUN" %in% names(dot.args)) {
-    p$arrivals.FUN <- dot.args$births.FUN
-    p$births.FUN <- dot.args$births.FUN <- NULL
+    p[["arrivals.FUN"]] <- dot.args[["births.FUN"]]
+    p[["births.FUN"]] <- dot.args[["births.FUN"]] <- NULL
     stop("EpiModel 1.7.0+ renamed the birth function births.FUN to
          arrivals.FUN. ", "See documentation for details.", call. = FALSE)
   }
   if ("deaths.FUN" %in% names(dot.args)) {
-    p$departures.FUN <- dot.args$deaths.FUN
-    p$deaths.FUN <- dot.args$deaths.FUN <- NULL
+    p[["departures.FUN"]] <- dot.args[["deaths.FUN"]]
+    p[["deaths.FUN"]] <- dot.args[["deaths.FUN"]] <- NULL
     stop("EpiModel 1.7.0+ renamed the death function deaths.FUN to
          departures.FUN. ", "See documentation for details.", call. = FALSE)
   }
 
   if ("depend" %in% names(dot.args)) {
-    p$resimulate.network <- dot.args$depend
+    p[["resimulate.network"]] <- dot.args[["depend"]]
     stop("EpiModel >= 2.0 has renamed the control.net setting `depend` to ",
          "`resimulate.network`. Update your code accordingly.",
          call. = FALSE)
@@ -753,21 +864,21 @@ control.net <- function(type,
 
   ## Module classification
   bi.mods <- grep(".FUN", names(formal.args), value = TRUE)
-  p$bi.mods <- character()
+  p[["bi.mods"]] <- character()
   bi.nms <- bi.mods
   index <- 1
-  if (is.null(p$type)) {
+  if (is.null(p[["type"]])) {
     for (i in 1:length(bi.mods)) {
       if (!is.null(p[[bi.mods[i]]])) {
-        p$bi.mods[index] <- bi.mods[i]
+        p[["bi.mods"]][index] <- bi.mods[i]
         index <- index + 1
       }
     }
   } else{
-    p$bi.mods <- bi.mods
+    p[["bi.mods"]] <- bi.mods
   }
-  p$user.mods <- grep(".FUN", names(dot.args), value = TRUE)
-  p$f.names <- c(p$bi.mods, p$user.mods)
+  p[["user.mods"]] <- grep(".FUN", names(dot.args), value = TRUE)
+  p[["f.names"]] <- c(p[["bi.mods"]], p[["user.mods"]])
 
   ## Defaults and checks
 
@@ -786,44 +897,44 @@ control.net <- function(type,
       }
     }
 
-    if (!is.null(p$type) && sum(flag1, na.rm = TRUE) != length(flag1)) {
+    if (!is.null(p[["type"]]) && sum(flag1, na.rm = TRUE) != length(flag1)) {
       stop("Control parameter 'type' must be null if any user defined base
            modules are present", call. = FALSE)
     }
   }
 
-  if (!is.null(p$type) && length(p$user.mods) > 0) {
+  if (!is.null(p[["type"]]) && length(p[["user.mods"]]) > 0) {
     stop("Control parameter 'type' must be null if any user specified modules
          are present", call. = FALSE)
   }
 
-  if (is.null(p$nsteps)) {
+  if (is.null(p[["nsteps"]])) {
     stop("Specify nsteps",
          call. = FALSE)
   }
 
   if (missing(attr.rules)) {
-    p$attr.rules <- list()
+    p[["attr.rules"]] <- list()
   }
 
-  if (!is.null(p$epi.by)) {
-    if (length(p$epi.by) > 1) {
+  if (!is.null(p[["epi.by"]])) {
+    if (length(p[["epi.by"]]) > 1) {
       stop("Length of epi.by currently limited to 1")
     } else {
-      p$epi.by <- epi.by
+      p[["epi.by"]] <- epi.by
     }
   }
 
-  if (is.null(p$save.network)) {
-    p$save.network <- TRUE
+  if (is.null(p[["save.network"]])) {
+    p[["save.network"]] <- TRUE
   }
-  if (p$tergmLite == TRUE) {
-    p$save.network <- FALSE
+  if (p[["tergmLite"]] == TRUE) {
+    p[["save.network"]] <- FALSE
   }
-  if (p$tergmLite == TRUE & p$resimulate.network == FALSE) {
+  if (p[["tergmLite"]] == TRUE & p[["resimulate.network"]] == FALSE) {
     message("Because tergmLite = TRUE, resetting resimulate.network = TRUE",
             call. = FALSE)
-    p$resimulate.network <- TRUE
+    p[["resimulate.network"]] <- TRUE
   }
 
   ## Output
@@ -853,9 +964,9 @@ control.net <- function(type,
 crosscheck.net <- function(x, param, init, control) {
   check.control.class("net", "EpiModel crosscheck.net")
 
-  if (!is.null(control$type) && length(control$user.mods) == 0) {
+  if (!is.null(control[["type"]]) && length(control[["user.mods"]]) == 0) {
 
-    if (control$start == 1 && control$skip.check == FALSE) {
+    if (control[["start"]] == 1 && control[["skip.check"]] == FALSE) {
 
       # Main class check ----------------------------------------------------
       if (class(x) != "netest" && class(x) != "netsim") {
@@ -873,7 +984,7 @@ crosscheck.net <- function(x, param, init, control) {
       }
 
       # Pull network object from netest object
-      nw <- x$fit$network
+      nw <- x[["fit"]][["network"]]
 
       # Defaults ------------------------------------------------------------
 
@@ -884,12 +995,12 @@ crosscheck.net <- function(x, param, init, control) {
       nGroups <- length(unique(get_vertex_attribute(nw, "group")))
       nGroups <- ifelse(nGroups == 2, 2, 1)
 
-      if (nGroups == 2 & is.null(control$pid.prefix)) {
-        control$pid.prefix <- c("g1.", "g2.")
+      if (nGroups == 2 & is.null(control[["pid.prefix"]])) {
+        control[["pid.prefix"]] <- c("g1.", "g2.")
       }
 
-      if (statOnNw == TRUE && is.null(control$attr.rules$status)) {
-        control$attr.rules$status <- "s"
+      if (statOnNw == TRUE && is.null(control[["attr.rules"]][["status"]])) {
+        control[["attr.rules"]][["status"]] <- "s"
       }
 
 
@@ -907,12 +1018,12 @@ crosscheck.net <- function(x, param, init, control) {
       }
 
       # Check consistency of status vector to network structure
-      if (!is.null(init$status.vector)) {
-        if (length(init$status.vector) != network.size(nw)) {
+      if (!is.null(init[["status.vector"]])) {
+        if (length(init[["status.vector"]]) != network.size(nw)) {
           stop("Length of status.vector is unequal to size of initial network")
         }
-        svals <- sort(unique(init$status.vector))
-        if (control$type == "SIR") {
+        svals <- sort(unique(init[["status.vector"]]))
+        if (control[["type"]] == "SIR") {
           if (any(svals %in% c("s", "i", "r") == FALSE)) {
             stop("status.vector contains values other than \"s\", \"i\",
                  and \"r\" ",
@@ -927,44 +1038,44 @@ crosscheck.net <- function(x, param, init, control) {
       }
 
       # Two-group model checks for inital conditions
-      if (nGroups == 2 & is.null(init$i.num.g2) &
-          is.null(init$status.vector) & statOnNw == FALSE) {
+      if (nGroups == 2 & is.null(init[["i.num.g2"]]) &
+          is.null(init[["status.vector"]]) & statOnNw == FALSE) {
         stop("Specify i.num.g2 for two-group model simulations", call. = FALSE)
       }
 
       # Recovery rate and initial recovered checks
-      if (control$type %in% c("SIR", "SIS")) {
-        if (is.null(param$rec.rate)) {
+      if (control[["type"]] %in% c("SIR", "SIS")) {
+        if (is.null(param[["rec.rate"]])) {
           stop("Specify rec.rate in param.net", call. = FALSE)
         }
-        if (nGroups == 2 & is.null(param$rec.rate.g2)) {
+        if (nGroups == 2 & is.null(param[["rec.rate.g2"]])) {
           stop("Specify rec.rate.g2 in param.net", call. = FALSE)
         }
       }
-      if (control$type == "SIR") {
-        if (is.null(init$r.num) & is.null(init$status.vector) &
+      if (control[["type"]] == "SIR") {
+        if (is.null(init[["r.num"]]) & is.null(init[["status.vector"]]) &
             statOnNw == FALSE) {
           stop("Specify r.num in init.net", call. = FALSE)
         }
-        if (nGroups == 2 & is.null(init$r.num.g2) &
-            is.null(init$status.vector) & statOnNw == FALSE) {
+        if (nGroups == 2 & is.null(init[["r.num.g2"]]) &
+            is.null(init[["status.vector"]]) & statOnNw == FALSE) {
           stop("Specify r.num.g2 in init.net", call. = FALSE)
         }
       }
 
       # Check demographic parameters for two-group models
-      if (nGroups == 2 & param$vital == TRUE) {
-        if (is.null(param$a.rate.g2)) {
+      if (nGroups == 2 & param[["vital"]] == TRUE) {
+        if (is.null(param[["a.rate.g2"]])) {
           stop("Specify a.rate.g2 in param.net", call. = FALSE)
         }
-        if (is.null(param$ds.rate.g2)) {
+        if (is.null(param[["ds.rate.g2"]])) {
           stop("Specify ds.rate.g2 in param.net", call. = FALSE)
         }
-        if (is.null(param$di.rate.g2)) {
+        if (is.null(param[["di.rate.g2"]])) {
           stop("Specify di.rate.g2 in param.net", call. = FALSE)
         }
-        if (control$type == "SIR") {
-          if (is.null(param$dr.rate.g2)) {
+        if (control[["type"]] == "SIR") {
+          if (is.null(param[["dr.rate.g2"]])) {
             stop("Specify dr.rate.g2 in param.net", call. = FALSE)
           }
         }
@@ -972,28 +1083,28 @@ crosscheck.net <- function(x, param, init, control) {
 
     }
 
-    if (control$start > 1) {
+    if (control[["start"]] > 1) {
 
-      control$resimulate.network <- TRUE
+      control[["resimulate.network"]] <- TRUE
 
-      if (control$skip.check == FALSE) {
+      if (control[["skip.check"]] == FALSE) {
         if (class(x) != "netsim") {
           stop("x must be a netsim object if control setting start > 1",
                call. = FALSE)
         }
-        if (is.null(x$attr)) {
+        if (is.null(x[["attr"]])) {
           stop("x must contain attr to restart simulation, see save.other ",
                "control setting", call. = FALSE)
         }
-        if (is.null(x$network)) {
+        if (is.null(x[["network"]])) {
           stop("x must contain network object to restart simulation, ",
                call. = FALSE)
         }
-        if (control$nsteps < control$start) {
+        if (control[["nsteps"]] < control[["start"]]) {
           stop("control setting nsteps must be > control setting start in ",
                "restarted simulations", call. = FALSE)
         }
-        if (control$start > x$control$nsteps + 1) {
+        if (control[["start"]] > x[["control"]][["nsteps"]] + 1) {
           stop("control setting start must be 1 greater than the nsteps in
                the ", "prior simulation", call. = FALSE)
         }
@@ -1005,13 +1116,13 @@ crosscheck.net <- function(x, param, init, control) {
 
 
     ## Assign modules based on group parameter
-    if (!is.null(control$type)) {
+    if (!is.null(control[["type"]])) {
       def <- grep(".FUN", names(control))
       args <- names(control)[def]
       flag <- length(grep(".g2", names(param)))
 
       if (flag == 0) {
-        for (i in 1:length(args)) {
+        for (i in seq_along(args)) {
           if (is.null(control[[args[i]]])) {
             temp <- get(gsub(".FUN", ".net", args[i]))
             control[[args[i]]] <- temp
@@ -1020,7 +1131,7 @@ crosscheck.net <- function(x, param, init, control) {
         }
       }
       else {
-        for (i in 1:length(args)) {
+        for (i in seq_along(args)) {
           if (is.null(control[[args[i]]])) {
             temp <- get(gsub(".FUN", ".2g.net", args[i]))
             control[[args[i]]] <- temp
@@ -1031,7 +1142,7 @@ crosscheck.net <- function(x, param, init, control) {
     }
   }
 
-  if (!is.null(control$type) && length(control$user.mods) > 0) {
+  if (!is.null(control[["type"]]) && length(control[["user.mods"]]) > 0) {
     stop("Control setting 'type' must be NULL if any user-specified modules
          specified.", call. = FALSE)
   }
