@@ -304,22 +304,8 @@ discord_edgelist <- function(dat, at, network = 1, infstat = "i") {
 
   status <- get_attr(dat, "status")
   active <- get_attr(dat, "active")
-  tergmLite <- get_control(dat, "tergmLite")
-  resimulate.network <- get_control(dat, "resimulate.network")
 
-  if (tergmLite == TRUE) {
-    el <- dat$el[[network]]
-  } else {
-    if (!is.null(dat$temp$nw_list)) {
-      if (resimulate.network == FALSE) {
-        el <- network::as.edgelist(dat$temp$nw_list[[at]])
-      } else {
-        el <- network::as.edgelist(dat$nw[[1]])
-      }
-    } else {
-      el <- networkDynamic::get.dyads.active(dat$nw[[network]], at = at)
-    }
-  }
+  el <- get_edgelist(dat, network)
 
   del <- NULL
   if (nrow(el) > 0) {
@@ -373,11 +359,8 @@ set_transmat <- function(dat, del, at) {
   del[["sus"]] <- get_unique_ids(dat, del[["sus"]])
   del[["inf"]] <- get_unique_ids(dat, del[["inf"]])
 
-  if (at != 2) {
-    del <- rbind(dat$stats$transmat, del)
-  }
-
-  dat$stats$transmat <- del
+  # when `dat$stats$transmat` is `NULL` the right hand side evaluate to `del`
+  dat$stats$transmat <- rbind(dat$stats$transmat, del)
 
   return(dat)
 }
