@@ -19,14 +19,8 @@ initialize.net <- function(x, param, init, control, s) {
   if (control$start == 1) {
 
     # Master Data List --------------------------------------------------------
-    dat <- list()
-    dat$param <- param
-    dat$init <- init
-    dat$control <- control
+    dat <- create_dat_object(param, init, control)
 
-    dat$attr <- list()
-    dat$stats <- list()
-    dat$temp <- list()
     dat$nwparam <- list()
     dat$nwparam[[1]] <- x[-which(names(x) == "fit")]
 
@@ -66,7 +60,7 @@ initialize.net <- function(x, param, init, control, s) {
     # Conversions for tergmLite
     tergmLite <- get_control(dat, "tergmLite")
     if (tergmLite == TRUE) {
-      dat <- tergmLite::init_tergmLite(dat)
+      dat <- init_tergmLite(dat)
     }
 
 
@@ -75,11 +69,9 @@ initialize.net <- function(x, param, init, control, s) {
 
     # Restart/Reinit Simulations ----------------------------------------------
   } else if (control$start > 1) {
-    dat <- list()
+    dat <- create_dat_object(param = x$param, control = control)
 
     dat$nw <- x$network[[s]]
-    dat$param <- x$param
-    dat$control <- control
     dat$nwparam <- x$nwparam
     if (is.null(dat$control$isTERGM)) {
       nwparam <- get_nwparam(dat)
@@ -90,7 +82,6 @@ initialize.net <- function(x, param, init, control, s) {
     names(dat$epi) <- names(x$epi)
     dat$attr <- x$attr[[s]]
     dat$stats <- sapply(x$stats, function(var) var[[s]])
-    dat$temp <- list()
   }
 
   return(dat)
@@ -134,12 +125,14 @@ initialize.net <- function(x, param, init, control, s) {
 init_status.net <- function(dat) {
 
   type <- get_control(dat, "type", override.null.error = TRUE)
+  type <- if (is.null(type)) "None" else type
+
   nsteps <- get_control(dat, "nsteps")
   tergmLite <- get_control(dat, "tergmLite")
   vital <- get_param(dat, "vital")
   groups <- get_param(dat, "groups")
   status.vector <- get_init(dat, "status.vector", override.null.error = TRUE)
-  if (type %in% c("SIS", "SIR") && !is.null(type)) {
+  if (type %in% c("SIS", "SIR")) {
     rec.rate <- get_param(dat, "rec.rate")
   }
   if (vital == TRUE) {
@@ -149,7 +142,7 @@ init_status.net <- function(dat) {
 
   # Variables ---------------------------------------------------------------
   i.num <- get_init(dat, "i.num", override.null.error = TRUE)
-  if (type  == "SIR" && is.null(status.vector) && !is.null(type)) {
+  if (type  == "SIR" && is.null(status.vector)) {
     r.num <- get_init(dat, "r.num")
   }
 
@@ -157,8 +150,16 @@ init_status.net <- function(dat) {
 
   if (groups == 2) {
     group <- get_attr(dat, "group")
+    if (!all(group %in% c(1, 2))) {
+      stop(
+        "When using the `group` attribute, the only authorized values",
+        " are 1 and 2.\n",
+        "The values found were: ", paste0(unique(group), collapse = ", ")
+      )
+    }
+
     i.num.g2 <- get_init(dat, "i.num.g2")
-    if (type  == "SIR" && is.null(status.vector) && !is.null(type)) {
+    if (type  == "SIR" && is.null(status.vector)) {
       r.num.g2 <- get_init(dat, "r.num.g2", override.null.error = TRUE)
     }
   } else {
@@ -179,7 +180,7 @@ init_status.net <- function(dat) {
       if (groups == 2) {
         status[sample(which(group == 2), size = i.num.g2)] <- "i"
       }
-      if (type == "SIR"  && !is.null(type)) {
+      if (type == "SIR") {
         status[sample(which(group == 1 & status == "s"), size = r.num)] <- "r"
         if (groups == 2) {
           status[sample(which(group == 2 & status == "s"),
@@ -214,7 +215,12 @@ init_status.net <- function(dat) {
 
   # Infection Time ----------------------------------------------------------
   ## Set up inf.time vector
-  if (!is.null(type)) {
+  if (type == "None") {
+    infTime <- rep(NA, num)
+    idsInf <- idsInf <- which(status == "i")
+    infTime[idsInf] <- 1
+    dat <- set_attr(dat, "infTime", infTime)
+  } else {
     idsInf <- which(status == "i")
     infTime <- rep(NA, length(status))
     infTime.vector <- get_init(dat, "infTime.vector",
@@ -246,11 +252,6 @@ init_status.net <- function(dat) {
       }
     }
 
-    dat <- set_attr(dat, "infTime", infTime)
-  } else {
-    infTime <- rep(NA, num)
-    idsInf <- idsInf <- which(status == "i")
-    infTime[idsInf] <- 1
     dat <- set_attr(dat, "infTime", infTime)
   }
 
