@@ -14,15 +14,16 @@
 nwupdate.net <- function(dat, at) {
 
   ## Attributes
-  type <- get_control(dat, "type", override.null.error = TRUE)
-  tergmLite <- get_control(dat, "tergmLite")
   status <- get_attr(dat, "status")
-  infTime <- get_attr(dat, "infTime")
   active <- get_attr(dat, "active")
   entrTime <- get_attr(dat, "entrTime")
   exitTime <- get_attr(dat, "exitTime")
 
-  # statOnNw <- "status" %in% dat$temp$nwterms
+  ## Controls
+  tergmLite <- get_control(dat, "tergmLite")
+  cumulative.edgelist <- get_control(
+    dat, "cumulative.edgelist", override.null.error = TRUE)
+
   resimulate.network <- get_control(dat, "resimulate.network")
   isTERGM <- get_control(dat, "isTERGM")
 
@@ -78,8 +79,8 @@ nwupdate.net <- function(dat, at) {
       dat$el[[1]] <- delete_vertices(dat$el[[1]], departures)
 
       if (dat$control$tergmLite.track.duration) {
-        dat$p[[1]]$state$nw0 %n% "lasttoggle" <-
-          delete_vertices(dat$p[[1]]$state$nw0 %n% "lasttoggle", departures)
+        dat$nw[[1]] %n% "lasttoggle" <-
+          delete_vertices(dat$nw[[1]] %n% "lasttoggle", departures)
       }
     }
   }
@@ -107,6 +108,18 @@ nwupdate.net <- function(dat, at) {
                                                    "status", status)
   }
 
+  # Cummulative edgelist
+  if (!is.null(cumulative.edgelist) && cumulative.edgelist) {
+
+    truncate.el.cuml <- get_control(
+      dat, "truncate.el.cuml", override.null.error = TRUE)
+    truncate.el.cuml <- if (is.null(truncate.el.cuml)) Inf else truncate.el.cuml
+
+    for (network in seq_along(dat[["nwparam"]])) {
+      dat <- update_cumulative_edgelist(dat, network, truncate.el.cuml)
+    }
+  }
+
   ## Output
   return(dat)
 }
