@@ -2,8 +2,8 @@
 #ifndef CHANGESTATS_H
 #define CHANGESTATS_H
 
-#include "edgetree.h"
-#include "changestat.h"
+#include "ergm_edgetree.h"
+#include "ergm_changestat.h"
 
 CHANGESTAT_FN(d_absdiffnodemix);
 CHANGESTAT_FN(d_absdiffby);
